@@ -351,13 +351,18 @@ gedit_document_finalize (GObject *object)
 
 	if (document->priv->uri != NULL)
 	{
+		GtkTextIter iter;
 		gchar *position;
 		gchar *lang_id = NULL;
 		GtkSourceLanguage *lang;
 
+		gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (document),			
+				&iter,
+				gtk_text_buffer_get_insert (GTK_TEXT_BUFFER (document)));
+
 		position = g_strdup_printf ("%d", 
-					    gedit_document_get_cursor (document));
-		
+					    gtk_text_iter_get_offset (&iter));
+
 		gedit_metadata_manager_set (document->priv->uri,
 					    "position",
 					    position);
@@ -556,7 +561,13 @@ gedit_document_real_loaded (GeditDocument *document, const GError *error)
 					   "position");
 	if (data != NULL)
 	{
-		gedit_document_set_cursor (document, atoi (data));
+		GtkTextIter iter;
+
+		gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (document),
+						    &iter,
+						    atoi (data));
+
+		gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (document), &iter);
 
 		g_free (data);
 	}
@@ -631,7 +642,7 @@ gedit_document_get_uri (const GeditDocument* doc)
 	gedit_debug (DEBUG_DOCUMENT, "");
 
 	if (doc->priv->uri == NULL)
-		return g_strdup_printf (_("%s %d"), _("Untitled"), doc->priv->untitled_number);
+		return g_strdup_printf (_("%s %d"), _("Unsaved Document"), doc->priv->untitled_number);
 	else
 	{
 		gchar *res;
@@ -649,13 +660,13 @@ gedit_document_get_short_name (const GeditDocument* doc)
 	gedit_debug (DEBUG_DOCUMENT, "");
 
 	if (doc->priv->uri == NULL)
-		return g_strdup_printf (_("%s %d"), _("Untitled"), doc->priv->untitled_number);
+		return g_strdup_printf (_("%s %d"), _("Unsaved Document"), doc->priv->untitled_number);
 	else
 	{
 		gchar *basename;
 		gchar *utf8_basename;
-		
-		basename = eel_uri_get_basename (doc->priv->uri);
+
+		basename = gedit_utils_uri_get_basename (doc->priv->uri);
 
 		if (basename != NULL) 
 		{
@@ -679,7 +690,7 @@ gedit_document_get_short_name (const GeditDocument* doc)
 			}
 			
 			/* there are problems */
-			utf8_basename = eel_make_valid_utf8 (basename);
+			utf8_basename = gedit_utils_make_valid_utf8 (basename);
 			g_free (basename);
 			return utf8_basename;
 		}
@@ -758,8 +769,6 @@ update_document_contents (GeditDocument        *doc,
 			  const GeditEncoding  *encoding,
 			  GError              **error)
 {
-	GtkTextIter iter, end;
-
 	PROFILE (
 		g_message ("Delete previous text %s: %.3f", uri, g_timer_elapsed (timer, NULL));
 	)
@@ -848,11 +857,8 @@ update_document_contents (GeditDocument        *doc,
 
 		gedit_document_begin_not_undoable_action (doc);
 
-		gedit_document_delete_text (doc, 0, -1);
-
 		/* Insert text in the buffer */
-		gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &iter, 0);
-		gtk_text_buffer_insert (GTK_TEXT_BUFFER (doc), &iter, converted_text, len);
+		gtk_text_buffer_set_text (GTK_TEXT_BUFFER (doc), converted_text, len);
 
 		PROFILE (
 			g_message ("Text inserted: %.3f", g_timer_elapsed (timer, NULL));
@@ -865,16 +871,6 @@ update_document_contents (GeditDocument        *doc,
 			g_free (converted_text);
 		}
 
-		/* We had a newline in the buffer to begin with. (The buffer always contains
-   		 * a newline, so we delete to the end of the buffer to clean up. 
-		 * FIXME: Is this really needed? - Paolo (Jan 8, 2004) */
-		gtk_text_buffer_get_end_iter (GTK_TEXT_BUFFER (doc), &end);
- 		gtk_text_buffer_delete (GTK_TEXT_BUFFER (doc), &iter, &end);
-
-		/* Place the cursor at the start of the document or and old cursor position
-		 * if reverting */
-		gedit_document_set_cursor (doc, 0);
-
 		gedit_document_end_not_undoable_action (doc);
 
 		PROFILE (
@@ -992,9 +988,7 @@ file_loaded_cb (GnomeVFSResult    result,
 		g_timer_destroy (timer);
 	})
 
-	/* conservative hackish fix, see #156992 */
-	if (GEDIT_IS_DOCUMENT (doc))
-		reset_temp_data (doc);
+	reset_temp_data (doc);
 
 	g_free (file_contents);	
 }
@@ -1659,31 +1653,6 @@ gedit_document_save_as (GeditDocument* doc, const gchar *uri,
 	return ret;
 }
 
-gboolean	
-gedit_document_save_a_copy_as (GeditDocument *doc, const gchar *uri, 
-			       const GeditEncoding *encoding, GError **error)
-{
-	gboolean m;
-	gboolean ret;
-
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_val_if_fail (doc != NULL, FALSE);
-	g_return_val_if_fail (doc->priv != NULL, FALSE);
-	g_return_val_if_fail (uri != NULL, FALSE);
-
-	if (encoding == NULL)
-		encoding = gedit_document_get_encoding (doc);
-	
-	m = gedit_document_get_modified (doc);
-
-	ret = gedit_document_save_as_real (doc, uri, encoding, FALSE, error);
-	
-	gtk_text_buffer_set_modified (GTK_TEXT_BUFFER (doc), m);	 
-
-	return ret;
-}
-
 #define MAX_LINK_LEVEL 256
 
 /* Does readlink() recursively until we find a real filename. */
@@ -1797,6 +1766,8 @@ gedit_document_save_as_real (GeditDocument* doc, const gchar *uri, const GeditEn
 	gint retval;
 	gboolean res;
 	gboolean add_cr;
+	GtkTextIter start_iter;
+	GtkTextIter end_iter;
 	
 	gedit_debug (DEBUG_DOCUMENT, "");
 
@@ -1820,7 +1791,7 @@ gedit_document_save_as_real (GeditDocument* doc, const gchar *uri, const GeditEn
 		gchar *scheme_string;
 
 		gchar *temp = gnome_vfs_get_uri_scheme (uri);
-                scheme_string = eel_make_valid_utf8 (temp);
+		scheme_string = gedit_utils_make_valid_utf8 (temp);
 		g_free (temp);
 
 		if (scheme_string != NULL)
@@ -1912,8 +1883,10 @@ gedit_document_save_as_real (GeditDocument* doc, const gchar *uri, const GeditEn
 		goto out;
 	}
 
-	chars = gedit_document_get_chars (doc, 0, -1);
-	
+	gtk_text_buffer_get_bounds (GTK_TEXT_BUFFER (doc), &start_iter, &end_iter);
+	chars = gtk_text_buffer_get_slice (GTK_TEXT_BUFFER (doc),
+					   &start_iter, &end_iter, TRUE);
+
 	if (encoding != gedit_encoding_get_utf8 ())
 	{
 		GError *conv_error = NULL;
@@ -2100,44 +2073,6 @@ gedit_document_get_deleted (GeditDocument *doc)
 	return deleted;
 }
 
-/**
- * gedit_document_get_char_count:
- * @doc: a #GeditDocument 
- * 
- * Gets the number of characters in the buffer; note that characters
- * and bytes are not the same, you can't e.g. expect the contents of
- * the buffer in string form to be this many bytes long. 
- * 
- * Return value: number of characters in the document
- **/
-gint 
-gedit_document_get_char_count (const GeditDocument *doc)
-{
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_val_if_fail (doc != NULL, FALSE);
-
-	return gtk_text_buffer_get_char_count (GTK_TEXT_BUFFER (doc));
-}
-
-/**
- * gedit_document_get_line_count:
- * @doc: a #GeditDocument 
- * 	
- * Obtains the number of lines in the buffer. 
- * 
- * Return value: number of lines in the document
- **/
-gint 
-gedit_document_get_line_count (const GeditDocument *doc)
-{
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_val_if_fail (doc != NULL, FALSE);
-
-	return gtk_text_buffer_get_line_count (GTK_TEXT_BUFFER (doc));
-}
-
 void 
 gedit_document_revert (GeditDocument *doc)
 {
@@ -2168,18 +2103,6 @@ gedit_document_insert_text (GeditDocument *doc, gint pos, const gchar *text, gin
 	gtk_text_buffer_insert (GTK_TEXT_BUFFER (doc), &iter, text, len);
 }
 
-void 
-gedit_document_insert_text_at_cursor (GeditDocument *doc, const gchar *text, gint len)
-{
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-	g_return_if_fail (text != NULL);
-	g_return_if_fail (g_utf8_validate (text, len, NULL));
-
-	gtk_text_buffer_insert_at_cursor (GTK_TEXT_BUFFER (doc), text, len);
-}
-
 void 
 gedit_document_delete_text (GeditDocument *doc, gint start, gint end)
 {
@@ -2686,50 +2609,6 @@ gedit_document_replace_all (GeditDocument *doc,
 	return cont;
 }
 
-guint
-gedit_document_get_line_at_offset (const GeditDocument *doc, guint offset)
-{
-	GtkTextIter iter;
-	
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
-
-	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &iter, offset);
-	
-	return gtk_text_iter_get_line (&iter);
-}
-
-gint 
-gedit_document_get_cursor (GeditDocument *doc)
-{
-	GtkTextIter iter;
-	
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_val_if_fail (GEDIT_IS_DOCUMENT (doc), 0);
-
-	gtk_text_buffer_get_iter_at_mark (GTK_TEXT_BUFFER (doc),			
-			&iter,
-			gtk_text_buffer_get_insert (GTK_TEXT_BUFFER (doc)));
-
-	return gtk_text_iter_get_offset (&iter); 
-}
-
-void
-gedit_document_set_cursor (GeditDocument *doc, gint cursor)
-{
-	GtkTextIter iter;
-	
-	gedit_debug (DEBUG_DOCUMENT, "");
-
-	g_return_if_fail (GEDIT_IS_DOCUMENT (doc));
-	
-	/* Place the cursor at the requested position */
-	gtk_text_buffer_get_iter_at_offset (GTK_TEXT_BUFFER (doc), &iter, cursor);
-	gtk_text_buffer_place_cursor (GTK_TEXT_BUFFER (doc), &iter);
-}
-
 void
 gedit_document_set_selection (GeditDocument *doc, gint start, gint end)
 {
