@@ -40,8 +40,8 @@
 
 
 /* some common error strings, %s must be a file path */
-#define MISSING_FILE    N_("Could not find \"%s\". Please, reinstall gedit.")
-#define MISSING_WIDGETS N_("Could not find the required widgets inside\"%s\". Please, reinstall gedit.")
+#define MISSING_FILE    N_("Could not find \"%s\". Please, reinstall gedit.\n")
+#define MISSING_WIDGETS N_("Could not find the required widgets inside\"%s\". Please, reinstall gedit.\n")
 
 
 void	gedit_utils_flash     (const gchar *msg);
@@ -91,6 +91,16 @@ gchar *gedit_utils_get_stdin (void);
 
 void gedit_warning (GtkWindow *parent, gchar *format, ...);
 
+gchar *gedit_utils_str_middle_truncate (const char *string,
+					guint truncate_length);
+
+gchar *gedit_utils_make_valid_utf8 (const char *name);
+
+gchar *gedit_utils_uri_get_basename (const char *uri);
+
+gchar *gedit_utils_uri_get_dirname (const char *uri);
+
+
 #endif /* __GEDIT_UTILS_H__ */
 
 
