@@ -56,17 +56,13 @@ static void
 sample_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 {
 	GeditDocument *doc;
-	GeditView *view;
 	gchar *user_name;
 	gchar *user_name_utf8;
 	const gchar *temp;
-	
+
 	gedit_debug (DEBUG_PLUGINS, "");
 
-	view = gedit_get_active_view ();
-	g_return_if_fail (view != NULL);
-	
-	doc = gedit_view_get_document (view);
+	doc = gedit_get_active_document ();
 	g_return_if_fail (doc != NULL);
 
 	temp = g_get_real_name ();
@@ -93,8 +89,8 @@ sample_cb (BonoboUIComponent *uic, gpointer user_data, const gchar* verbname)
 	}
 
 	gedit_document_begin_user_action (doc);
-	
-	gedit_document_insert_text_at_cursor (doc, user_name_utf8, -1);
+
+	gtk_text_buffer_insert_at_cursor (GTK_TEXT_BUFFER (doc), user_name_utf8, -1);
 
 	gedit_document_end_user_action (doc);
 
